@@ -19,7 +19,7 @@ sub type_code {
 }
 
 
-no Moose;
+no Any::Moose;
 
 
 1;
